@@ -65,46 +65,46 @@
 #'
 #' # Translation with data source --------------------------------------------
 #' \donttest{
-#' hflights <- tbl(hflights_postgres(), "hflights")
+#' flights <- tbl(nycflights13_postgres(), "flights")
 #' # Note distinction between integers and reals
-#' translate_sql(Month == 1, tbl = hflights)
-#' translate_sql(Month == 1L, tbl = hflights)
+#' translate_sql(month == 1, tbl = flights)
+#' translate_sql(month == 1L, tbl = flights)
 #'
 #' # Know how to translate most simple mathematical expressions
-#' translate_sql(Month %in% 1:3, tbl = hflights)
-#' translate_sql(Month >= 1L & Month <= 3L, tbl = hflights)
-#' translate_sql((Month >= 1L & Month <= 3L) | Carrier == "AA", tbl = hflights)
+#' translate_sql(month %in% 1:3, tbl = flights)
+#' translate_sql(month >= 1L & month <= 3L, tbl = flights)
+#' translate_sql((month >= 1L & month <= 3L) | carrier == "AA", tbl = flights)
 #'
 #' # Some R functions don't have equivalents in SQL: where possible they
 #' # will be translated to the equivalent
-#' translate_sql(xor(Month <= 3L, Carrier == "AA"), tbl = hflights)
+#' translate_sql(xor(month <= 3L, carrier == "AA"), tbl = flights)
 #'
 #' # Local variables will be automatically inserted into the SQL
 #' x <- 5L
-#' translate_sql(Month == x, tbl = hflights)
+#' translate_sql(month == x, tbl = flights)
 #'
 #' # By default all computation will happen in sql
-#' translate_sql(Month < 1 + 1, source = hflights)
+#' translate_sql(month < 1 + 1, source = flights)
 #' # Use local to force local evaluation
-#' translate_sql(Month < local(1 + 1), source = hflights)
+#' translate_sql(month < local(1 + 1), source = flights)
 #'
 #' # This is also needed if you call a local function:
 #' inc <- function(x) x + 1
-#' translate_sql(Month == inc(x), source = hflights)
-#' translate_sql(Month == local(inc(x)), source = hflights)
+#' translate_sql(month == inc(x), source = flights)
+#' translate_sql(month == local(inc(x)), source = flights)
 #'
 #' # Windowed translation --------------------------------------------
-#' planes <- arrange(group_by(hflights, TailNum), desc(DepTime))
+#' planes <- arrange(group_by(flights, tailnum), desc(DepTime))
 #'
-#' translate_sql(DepTime > mean(DepTime), tbl = planes, window = TRUE)
-#' translate_sql(DepTime == min(DepTime), tbl = planes, window = TRUE)
+#' translate_sql(dep_time > mean(dep_time), tbl = planes, window = TRUE)
+#' translate_sql(dep_time == min(dep_time), tbl = planes, window = TRUE)
 #'
 #' translate_sql(rank(), tbl = planes, window = TRUE)
-#' translate_sql(rank(DepTime), tbl = planes, window = TRUE)
-#' translate_sql(ntile(DepTime, 2L), tbl = planes, window = TRUE)
-#' translate_sql(lead(DepTime, 2L), tbl = planes, window = TRUE)
-#' translate_sql(cumsum(DepDelay), tbl = planes, window = TRUE)
-#' translate_sql(order_by(DepDelay, cumsum(DepDelay)), tbl = planes, window = TRUE)
+#' translate_sql(rank(dep_time), tbl = planes, window = TRUE)
+#' translate_sql(ntile(dep_time, 2L), tbl = planes, window = TRUE)
+#' translate_sql(lead(dep_time, 2L), tbl = planes, window = TRUE)
+#' translate_sql(cumsum(dep_time), tbl = planes, window = TRUE)
+#' translate_sql(order_by(dep_time, cumsum(dep_time)), tbl = planes, window = TRUE)
 #' }
 translate_sql <- function(..., tbl = NULL, env = parent.frame(), variant = NULL,
                           window = FALSE) {
@@ -129,12 +129,12 @@ translate_sql_q <- function(expr, tbl = NULL, env = parent.frame(),
   if (!is.null(env) && !is.null(tbl)) {
     expr <- partial_eval(expr, tbl, env)
   }
-  variant <- variant %||% translate_env(tbl)
+  variant <- variant %||% src_translate_env(tbl)
 
   # Translate partition ordering and grouping, and make available
   if (window && !is.null(tbl)) {
-    group_by <- translate_sql_q(tbl$group_by, variant = variant, env = NULL)
-    order_by <- translate_sql_q(tbl$order_by, variant = variant, env = NULL)
+    group_by <- translate_sql_q(tbl$group_by, tbl, variant = variant, env = NULL)
+    order_by <- translate_sql_q(tbl$order_by, tbl, variant = variant, env = NULL)
     old <- set_partition(group_by, order_by)
     on.exit(set_partition(old))
   }
@@ -149,11 +149,10 @@ translate_sql_q <- function(expr, tbl = NULL, env = parent.frame(),
   sql(unlist(pieces))
 }
 
-translate_env <- function(x) UseMethod("translate_env")
 #' @export
-translate_env.tbl_sql <- function(x) translate_env(x$src)
+src_translate_env.tbl_sql <- function(x) src_translate_env(x$src)
 #' @export
-translate_env.NULL <- function(x) {
+src_translate_env.NULL <- function(x) {
   sql_variant(
     base_scalar,
     base_agg,
