@@ -89,7 +89,7 @@ namespace dplyr {
     template <>
     class Collecter_Impl<STRSXP> : public Collecter {
     public:
-        Collecter_Impl( int n_ ): data( n_ ){}
+        Collecter_Impl( int n_ ): data( n_, NA_STRING ){}
         
         void collect( const SlicingIndex& index, SEXP v ){
             if( TYPEOF(v) == STRSXP ){
@@ -332,6 +332,7 @@ namespace dplyr {
             return new Collecter_Impl<REALSXP>(n) ;
         case LGLSXP: return new Collecter_Impl<LGLSXP>(n) ;
         case STRSXP: return new Collecter_Impl<STRSXP>(n) ;
+        case VECSXP: return new Collecter_Impl<VECSXP>(n) ;
         default: break ;
         }
         return 0 ;
