@@ -1,6 +1,8 @@
 #ifndef dplyr_tools_tools_H
 #define dplyr_tools_tools_H
 
+#include <tools/Encoding.h>
+#include <tools/StringUTF8.h>
 #include <tools/DotsOf.h>
 #include <tools/Call.h>
 #include <tools/hash.h>
@@ -14,7 +16,6 @@
 #include <tools/ShrinkableVector.h>
 #include <tools/wrap_subset.h>
 #include <tools/get_all_second.h>
-#include <tools/JoinColumnSuffixer.h>
-#include <tools/DataDots.h>
+#include <tools/LazyDots.h>
 
 #endif
