@@ -4,13 +4,12 @@ using namespace Rcpp ;
 using namespace dplyr ;
 
 template <typename Data, typename Subsets>
-SEXP summarise_grouped(const DataFrame& df, List args, const DataDots& dots){
+SEXP summarise_grouped(const DataFrame& df, const LazyDots& dots){
     Data gdf(df) ;
     
     int nexpr = dots.size() ;
     int nvars = gdf.nvars() ;
-    CharacterVector results_names = args.names() ;
-    check_not_groups(results_names, gdf);
+    check_not_groups(dots, gdf);
     NamedListAccumulator<Data> accumulator ;
 
     int i=0;
@@ -22,20 +21,18 @@ SEXP summarise_grouped(const DataFrame& df, List args, const DataDots& dots){
     Shelter<SEXP> __ ;
     for( int k=0; k<nexpr; k++, i++ ){
         Rcpp::checkUserInterrupt() ;
+        const Lazy& lazy = dots[k] ;
+        const Environment& env = lazy.env() ;
         
-        Environment env = dots.envir(k) ;
-
-        Result* res = get_handler( args[dots.expr_index(k)], subsets, env ) ;
+        Result* res = get_handler( lazy.expr(), subsets, env ) ;
         
         // if we could not find a direct Result
         // we can use a GroupedCallReducer which will callback to R
-        if( !res ) res = new GroupedCallReducer<Data, Subsets>( args[dots.expr_index(k)], subsets, env) ;
-        
+        if( !res ) res = new GroupedCallReducer<Data, Subsets>( lazy.expr(), subsets, env) ;
         
         SEXP result = __( res->process(gdf) ) ;
-        SEXP name = results_names[dots.expr_index(k)] ;
-        accumulator.set( name, result );
-        subsets.input( Symbol(name), SummarisedVariable(result) ) ;
+        accumulator.set( lazy.name(), result );
+        subsets.input( Symbol(lazy.name()), SummarisedVariable(result) ) ;
         delete res;
     }
 
@@ -43,29 +40,27 @@ SEXP summarise_grouped(const DataFrame& df, List args, const DataDots& dots){
 }
 
 
-SEXP summarise_not_grouped(DataFrame df, List args, const DataDots& dots){
+SEXP summarise_not_grouped(DataFrame df, const LazyDots& dots){
     int nexpr = dots.size() ;
     if( nexpr == 0) return DataFrame() ;
     
-    CharacterVector names = args.names();
-
     LazySubsets subsets( df ) ;
     std::vector<SEXP> results ;
-    std::vector<SEXP> result_names ;
     NamedListAccumulator<DataFrame> accumulator ;
 
     Rcpp::Shelter<SEXP> __ ;
     for( int i=0; i<nexpr; i++){
         Rcpp::checkUserInterrupt() ;
         
-        SEXP name = names[dots.expr_index(i)] ;
-        Environment env = dots.envir(i) ;
-        Result* res = get_handler( args[i], subsets, env ) ;
+        const Lazy& lazy = dots[i] ;
+        Environment env = lazy.env() ;
+        Result* res = get_handler( lazy.expr(), subsets, env ) ;
+        
         SEXP result ;
         if(res) {
             result = __(res->process( FullDataFrame(df) )) ;
         } else {
-            result = __(CallProxy( args[dots.expr_index(i)], subsets, env).eval()) ;
+            result = __(CallProxy( lazy.expr(), subsets, env).eval()) ;
         }
         delete res ;
         if( Rf_length(result) != 1 ){
@@ -74,22 +69,22 @@ SEXP summarise_not_grouped(DataFrame df, List args, const DataDots& dots){
               << Rf_length(result) ;
             stop(s.str()) ;
         }
-        subsets.input( Symbol(name), result ) ;
-        accumulator.set(name, result);
+        accumulator.set(lazy.name(), result);
+        subsets.input( Symbol(lazy.name()), result ) ;
     }
 
     return tbl_cpp( accumulator, 1 ) ;
 }
 
 // [[Rcpp::export]]
-SEXP summarise_impl( DataFrame df, List args, Environment env){
-    DataDots dots(env) ;
+SEXP summarise_impl( DataFrame df, LazyDots dots){
+    check_valid_colnames(df) ;
     if( is<RowwiseDataFrame>(df) ){
-        return summarise_grouped<RowwiseDataFrame, LazyRowwiseSubsets>( df, args, dots);
+        return summarise_grouped<RowwiseDataFrame, LazyRowwiseSubsets>( df, dots);
     } else if( is<GroupedDataFrame>( df ) ){
-        return summarise_grouped<GroupedDataFrame, LazyGroupedSubsets>( df, args, dots);
+        return summarise_grouped<GroupedDataFrame, LazyGroupedSubsets>( df, dots);
     } else {
-        return summarise_not_grouped( df, args, dots) ;
+        return summarise_not_grouped( df, dots) ;
     }
 }
 
